<?php

namespace Drupal\ww_publish;

use Drupal\Core\Field\FieldDefinitionInterface;

trait MediaFieldTrait {

  /**
   * Returns the media target bundle.
   *
   * @return string|null
   *   The name of the media target bundle if this is a media reference with a
   *   supported target type.
   */
  private function getMediaTargetBundle(FieldDefinitionInterface $field_definition) {
    $bundle = NULL;
    if (
      $field_definition->getSetting('handler') === 'default:media' &&
      $field_definition->getSetting('handler_settings') &&
      count($field_definition->getSetting('handler_settings')['target_bundles']) === 1
    ) {
      $bundle = reset($field_definition->getSetting('handler_settings')['target_bundles']);
    }
    return $bundle;
  }

  /**
   * Returns the media
   *
   * @param string $bundle
   *   The media bundle.
   * @param Object $image_component
   *   The image component.
   *
   * @return integer|null
   *   The media entity ID or NULL if none was found or created.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  private function createMediaImage($bundle, $image_component) {
    switch ($bundle) {
      // @todo Support other bundles names.
      case 'image':
        $image = new Image($image_component->id, $this->message, $this->config, $this->logger);
        if ($mediaEntity = $image->getMediaEntity()) {
          return $mediaEntity->id();
        } else {
          $this->logger->error('Image media entity could not be created for the component: <pre><code>@component</code></pre>', ['@component' => print_r($image_component, TRUE)]);
          return NULL;
        }

        break;
    }

    return NULL;
  }

}
